export class MarkupHighLight {
  private _textToBeHighLighted: string | string[];
  private _searchKey: string;
  private _caseInSensitive: boolean;
  constructor(
    text: string | string[] = "",
    searchKey: string = "",
    caseinSensitive = true
  ) {
    this._textToBeHighLighted = text;
    this._searchKey = searchKey;
    this._caseInSensitive = caseinSensitive;
  }

  public getTextToBeHighLighted(): string | string[] {
    return this._textToBeHighLighted;
  }

  public setTextToBeHighLighted(text: string | string[]) {
    this._textToBeHighLighted = text;
  }

  public getSearchKey(): string {
    return this._searchKey;
  }

  public setSearchKey(key: string) {
    this._searchKey = key;
  }

  public isCaseInSensitiveEnabled(): boolean {
    return this._caseInSensitive;
  }

  public toggleCaseInSensitiveEnabled(ignoreCase: boolean) {
    this._caseInSensitive = ignoreCase;
  }

  private getMatchingIndexes(tempText: string, searchKey: string) {
    let regex;
    let result;
    let indices = [];
    if (this._caseInSensitive) {
      regex = new RegExp(searchKey.toLowerCase(), "g");
    } else {
      regex = new RegExp(searchKey, "g");
    }
    let regexp = new RegExp(regex);
    if (this._caseInSensitive) {
      while ((result = regexp.exec(tempText.toLowerCase()))) {
        indices.push(result.index);
      }
    } else {
      while ((result = regexp.exec(tempText))) {
        indices.push(result.index);
      }
    }
    return indices;
  }

  private isListOfEmptyStrings(): Boolean {
    const emptyStringList = (this._textToBeHighLighted as string[]).filter(
      (str: string) => str === ""
    );
    if (emptyStringList.length === this._textToBeHighLighted.length) {
      return true;
    }
    return false;
  }

  public getHighLightedText(): string | string[] {
    if (this._searchKey === "") {
      return this._textToBeHighLighted;
    }
    if (
      this._textToBeHighLighted === "" ||
      this._textToBeHighLighted.length === 0
    ) {
      return "";
    }
    if (typeof this._textToBeHighLighted === "string") {
      return this.getHighLightedString(this._textToBeHighLighted);
    } else {
      if (this.isListOfEmptyStrings()) {
        return this._textToBeHighLighted.map(() => "");
      }
      return this.getListOfHighLightedStrings(this._textToBeHighLighted);
    }
  }

  private getHighLightedString(stringToBeHighLighted: string): string {
    let matchingIndexes: number[] = [];
    matchingIndexes = this.getMatchingIndexes(
      stringToBeHighLighted,
      this._searchKey
    );
    if(matchingIndexes.length === 0){
      return stringToBeHighLighted;
    }
    let finalString = "";
    matchingIndexes.forEach(idx => {
      let strIdx = 0;
      while (strIdx < stringToBeHighLighted.length) {
        if (strIdx === idx) {
          let highlightedSubString = stringToBeHighLighted.substr(
            strIdx,
            this._searchKey.length
          );
          finalString = finalString + `<mark>${highlightedSubString}</mark>`;
          strIdx = strIdx + this._searchKey.length;
        } else {
          finalString = finalString + stringToBeHighLighted[strIdx];
          strIdx++;
        }
      }
    });
    return finalString;
  }

  private getListOfHighLightedStrings(
    stringsToBeHighLighted: string[]
  ): string[] {
    let finalHighLightedString: string[] = [];
    stringsToBeHighLighted.forEach((stringToBeHighLighted: string) => {
      finalHighLightedString.push(
        this.getHighLightedString(stringToBeHighLighted)
      );
    });
    return finalHighLightedString;
  }

  public reset(){
    this._textToBeHighLighted = '';
    this._searchKey = '';
    this._caseInSensitive = true;
  }
}
