import { MarkupHighLight } from "../src/lib/markupHighLight";

describe("Test the MarkUpHighLight Library", function() {
  it("1. Check for empty search text with non-empty search key with case insensitive flag turned on", function() {
    let searchText = "";
    let searchKey = "he";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("");
  });
  it("2. Check for empty search text with non-empty search key with case insensitive flag turned off", function() {
    let searchText = "";
    let searchKey = "he";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("");
  });
  it("3. Check for empty search text with empty search key with case insensitive flag turned on", function() {
    let searchText = "";
    let searchKey = "";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("");
  });
  it("4. Check for empty search text with empty search key with case insensitive flag turned off", function() {
    let searchText = "";
    let searchKey = "";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("");
  });
  it("5. Check for non-empty search text with non-empty search key with case insensitive flag turned on", function() {
    let searchText = "Sample String One";
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("Sample <mark>Str</mark>ing One");
  });
  it("6. Check for non-empty search text with non-empty search key with case insensitive flag turned off", function() {
    let searchText = "Sample String One";
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual("Sample String One");
  });
  it("7. Check for list of empty search text with non-empty search key with case insensitive flag turned on", function() {
    let searchText = ["", "", ""];
    let searchKey = "he";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual(["", "", ""]);
  });
  it("8. Check for list of empty search text with non-empty search key with case insensitive flag turned off", function() {
    let searchText = ["", "", ""];
    let searchKey = "he";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual(["", "", ""]);
  });
  it("9. Check for list of empty search text with empty search key with case insensitive flag turned on", function() {
    let searchText = ["", "", ""];
    let searchKey = "";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual(["", "", ""]);
  });
  it("10. Check for list of empty search text with empty search key with case insensitive flag turned off", function() {
    let searchText = ["", "", ""];
    let searchKey = "";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual(["", "", ""]);
  });
  it("11. Check for list of non-empty search text with non-empty search key with case insensitive flag turned on", function() {
    let searchText = [
      "Sample String One",
      "Sample String two",
      "Sample String Three"
    ];
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual([
      "Sample <mark>Str</mark>ing One",
      "Sample <mark>Str</mark>ing two",
      "Sample <mark>Str</mark>ing Three"
    ]);
  });
  it("12. Check for list of non-empty search text with non-empty search key with case insensitive flag turned off", function() {
    let searchText = [
      "Sample String One",
      "Sample String two",
      "Sample String Three"
    ];
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual([
      "Sample String One",
      "Sample String two",
      "Sample String Three"
    ]);
  });
  it("13. Check for list of empty & non-empty search text with non-empty search key with case insensitive flag turned on", function() {
    let searchText = ["Sample String One", "", "Sample String Three"];
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual([
      "Sample <mark>Str</mark>ing One",
      "",
      "Sample <mark>Str</mark>ing Three"
    ]);
  });
  it("14. Check for list of empty & non-empty search text with non-empty search key with case insensitive flag turned off", function() {
    let searchText = ["Sample String One", "", "Sample String Three"];
    let searchKey = "str";
    const markupObject = new MarkupHighLight(searchText, searchKey, false);
    const result = markupObject.getHighLightedText();
    expect(result).toEqual(["Sample String One", "", "Sample String Three"]);
  });
});
